#!/bin/bash

# --------------------------------------------------------------------------
# Copyright 2011, C12G Labs S.L.
#
# This file is part of OpenNebula VMware Drivers.
#
# OpenNebula VMware Drivers is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or the hope That it will be useful, but (at your
# option) any later version.
#
# OpenNebula VMware Drivers is distributed in WITHOUT ANY WARRANTY;
# without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License
# along with OpenNebula VMware Drivers . If not, see
# <http://www.gnu.org/licenses/>
# --------------------------------------------------------------------------

#-------------------------------------------------------------------------------
# Install program for OpenNebula VMWare Drivers Addon. It will be installed in
# $ONE_LOCATION if defined, otherwise it'll be installed under /.
#
# To install in non-gcc platforms and to fine tune C flags, 
# change the CC and CCFLAGS
#-------------------------------------------------------------------------------

DIR=`dirname $0`
VERSION=2.9.80

#-------------------------------------------------------------------------------
# Path location
#-------------------------------------------------------------------------------
if [ -n "$ONE_LOCATION" ]; then
    BIN_LOCATION="$ONE_LOCATION/bin"
    LIB_LOCATION="$ONE_LOCATION/lib"
    ETC_LOCATION="$ONE_LOCATION/etc"
    VAR_LOCATION="$ONE_LOCATION/var"
    ADDON_DIR=$HOME
else
    BIN_LOCATION="/usr/bin"
    LIB_LOCATION="/usr/lib/one"
    ETC_LOCATION="/etc/one"
    VAR_LOCATION="/var/lib/one"
    ADDON_DIR=$(getent passwd|grep ^${ONE_USER:=oneadmin}:|cut -d: -f6)
fi

if [ "$1" != "nobuild" ]; then
    $DIR/build.sh
fi

# Make dirs and copy files

# tty_expect
cp $DIR/src/tty_expect/tty_expect $DESTDIR$BIN_LOCATION || error=true
chmod +x $DESTDIR$BIN_LOCATION/tty_expect

# lib
cp $DIR/lib/vmwarelib.rb $DESTDIR$LIB_LOCATION/ruby || error=true
cp $DIR/share/vmwarerc $DESTDIR$ETC_LOCATION || error=true
cp -p $DIR/share/fix_owner_perms.sh $DESTDIR$VAR_LOCATION/remotes/hooks || error=true

# vmm
mkdir -p $DESTDIR$VAR_LOCATION/remotes/vmm/vmware || error=true
mkdir $DESTDIR$ETC_LOCATION/vmm_sh &> /dev/null
cp -r $DIR/vmm/remotes/* $DESTDIR$VAR_LOCATION/remotes/vmm/vmware || error=true
cp -r $DIR/vmm/etc/* $DESTDIR$ETC_LOCATION/vmm_sh || error=true

# im
mkdir -p $DESTDIR$VAR_LOCATION/remotes/im/vmware.d || error=true
cp -r $DIR/im/remotes/* $DESTDIR$VAR_LOCATION/remotes/im/vmware.d || error=true

# image
cp $DIR/image/fs/* $DESTDIR$VAR_LOCATION/remotes/image/fs || error=true

# tm
mkdir $DESTDIR$ETC_LOCATION/tm_vmware &> /dev/null
mkdir $DESTDIR$LIB_LOCATION/tm_commands/vmware &> /dev/null
cp $DIR/tm/etc/tm_vmware.conf $DESTDIR$ETC_LOCATION/tm_vmware || error=true
cp $DIR/tm/commands/* $DESTDIR$LIB_LOCATION/tm_commands/vmware || error=true

mkdir -p $ADDON_DIR/.one/addons/vmware &> /dev/null
echo "$VERSION" > $ADDON_DIR/.one/addons/vmware/version &> /dev/null

# Report error or success
if [ -n "$error" ]; then
    echo "There was a problem with the installation"
else
    echo "VMWare Drivers Addon successfully installed"
    echo
    cat $DIR/share/oned.conf.vmware.README
fi
